#
# spec file for package ovirt-guest-agent
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1210
%define withprefix %_prefix
%else
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%endif
%{!?_initddir: %{expand: %%global _initddir %{_initrddir}}}
%{!?_rundir: %{expand: %%global _rundir %{_localstatedir}/run}}
%{!?_udevrulesdir: %{expand: %%global _udevrulesdir %{?withprefix}/lib/udev/rules.d}}

%global release_version 1
%define         major_version 1.0.14
Name:           ovirt-guest-agent
Version:        %major_version
Release:        1.1
Summary:        The oVirt Guest Agent
License:        Apache-2.0
Group:          System/Monitoring
Url:            http://wiki.ovirt.org/wiki/Category:Ovirt_guest_agent
Source0:        http://resources.ovirt.org/pub/src/ovirt-guest-agent/ovirt-guest-agent-%{major_version}.tar.bz2

%if 0%{?suse_version} >= 1210
BuildRequires:  fdupes
BuildRequires:  systemd
%endif
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  python-devel
BuildRequires:  sudo
BuildRequires:  udev
Requires:       %{name}-common = %{version}-%{release}

%package common
Summary:        Commonly used files of the oVirt Guest Agent
Group:          System/Monitoring
BuildArch:      noarch
%if %{?suse_version} >= 1210
BuildRequires:  python-pep8
%endif
Requires:       python-ethtool >= 0.4-1
Requires:       rpm-python
Requires:       sudo
Requires:       udev >= 095-14.23
Provides:       %{name} = %{version}-%{release}

%description
This is the oVirt management agent running inside the guest. The agent
interfaces with the oVirt manager, supplying heart-beat info as well as
run-time data from within the guest itself. The agent also accepts
control commands to be run executed within the OS (like: shutdown and
restart).

%description common
This is the oVirt management agent running inside the guest. The agent
interfaces with the oVirt manager, supplying heart-beat info as well as
run-time data from within the guest itself. The agent also accepts
control commands to be run executed within the OS (like: shutdown and
restart).

%prep
%setup -q -n ovirt-guest-agent-%{version}
sed "s@/run/ovirt-guest-agent.pid@%{_rundir}/ovirt-guest-agent.pid@g" -i ovirt-guest-agent/ovirt-guest-agent.py

%build

autoreconf -ivf

%configure \
    --with-sudohelper=sudo \
    --without-sso

make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot}

install -d -m 755 -p %{buildroot}%{_sbindir}
%if %{?suse_version} >= 1210
install -d 644 %{buildroot}%{_unitdir}
install -m 644 ovirt-guest-agent/ovirt-guest-agent.service %{buildroot}%{_unitdir}/ovirt-guest-agent.service
ln -s service %{buildroot}%{_sbindir}/rcovirt-guest-agent
%else
install -d -p -m 755 %{buildroot}%{_initrddir}
install -D -m 755 ovirt-guest-agent/ovirt-guest-agent.sles %{buildroot}%{_initrddir}/ovirt-guest-agent
ln -s %{_initddir}/ovirt-guest-agent %{buildroot}%{_sbindir}/rcovirt-guest-agent
%endif
install -d -m 755 -p %{buildroot}%{_udevrulesdir}
/bin/mv %{buildroot}/%{_sysconfdir}/udev/rules.d/55-ovirt-guest-agent.rules %{buildroot}%{_udevrulesdir}/55-ovirt-guest-agent.rules
%if 0%{?suse_version} >= 1210
%fdupes %{buildroot}%{_datadir}/ovirt-guest-agent
%endif

%pre common
# include the sudoers.d directory in /etc/sudoers if it does not already exist
grep "^#includedir %{_sysconfdir}/sudoers.d$" %{_sysconfdir}/sudoers > /dev/null || echo "#includedir %{_sysconfdir}/sudoers.d" >> %{_sysconfdir}/sudoers ||:

getent group ovirtagent >/dev/null || groupadd -r -g 175 ovirtagent
getent passwd ovirtagent > /dev/null || \
    /usr/sbin/useradd -u 175 -g 175 -o -r ovirtagent \
    -c "oVirt Guest Agent" -d %{_datadir}/ovirt-guest-agent -s /sbin/nologin
%if 0%{?suse_version} >= 1210
%service_add_pre ovirt-guest-agent.service
%endif
exit 0

%post common
/sbin/udevadm trigger --subsystem-match="virtio-ports" \
    --attr-match="name=com.redhat.rhevm.vdsm"

%if 0%{?suse_version} >= 1210
%service_add_post ovirt-guest-agent.service
%endif
exit 0

%preun common
if [ "$1" -eq 0 ]
then
%if 0%{?suse_version} >= 1210
    %service_del_preun ovirt-guest-agent.service
%else
    %stop_on_removal ovirt-guest-agent
%endif
    # /bin/systemctl stop ovirt-guest-agent.service > /dev/null 2>&1

    # Send an "uninstalled" notification to vdsm.
    VIRTIO=`grep "^device" %{_sysconfdir}/ovirt-guest-agent.conf | awk '{ print $3; }'`
    if [ -w $VIRTIO ]
    then
        # Non blocking uninstalled notification
        echo -e '{"__name__": "uninstalled"}\n' | dd of=$VIRTIO \
            oflag=nonblock status=noxfer conv=nocreat 1>& /dev/null || :
    fi
fi
exit 0

%postun common
if [ "$1" -eq 0 ]
then
%if 0%{?suse_version} >= 1210
    %service_del_postun ovirt-guest-agent.service
%else
    %insserv_cleanup
%endif
    # Let udev clear access rights
    /sbin/udevadm trigger --subsystem-match="virtio-ports" \
        --attr-match="name=com.redhat.rhevm.vdsm"
fi

if [ "$1" -ge 1 ]; then
%if 0%{?suse_version} >= 1210
    /bin/systemctl try-restart ovirt-guest-agent.service >/dev/null 2>&1 || :
%else
    true
%endif
fi
exit 0

%files common
%defattr(644,root,root,755)

%dir %attr (755,ovirtagent,ovirtagent) %{_localstatedir}/log/ovirt-guest-agent
%dir %attr (755,root,root) %{_datadir}/ovirt-guest-agent
%dir %attr (750,root,root) %{_sysconfdir}/sudoers.d

# Hook configuration directories
%dir %attr (755,root,root) %{_sysconfdir}/ovirt-guest-agent
%dir %attr (755,root,root) %{_sysconfdir}/ovirt-guest-agent/hooks.d
%dir %attr (755,root,root) %{_sysconfdir}/ovirt-guest-agent/hooks.d/before_migration
%dir %attr (755,root,root) %{_sysconfdir}/ovirt-guest-agent/hooks.d/after_migration
%dir %attr (755,root,root) %{_sysconfdir}/ovirt-guest-agent/hooks.d/before_hibernation
%dir %attr (755,root,root) %{_sysconfdir}/ovirt-guest-agent/hooks.d/after_hibernation

# Hook installation directories
%dir %attr (755,root,root) %{_datadir}/ovirt-guest-agent/scripts
%dir %attr (755,root,root) %{_datadir}/ovirt-guest-agent/scripts/hooks/
%dir %attr (755,root,root) %{_datadir}/ovirt-guest-agent/scripts/hooks/defaults
%dir %attr (755,root,root) %{_datadir}/ovirt-guest-agent/scripts/hooks/before_migration
%dir %attr (755,root,root) %{_datadir}/ovirt-guest-agent/scripts/hooks/after_migration
%dir %attr (755,root,root) %{_datadir}/ovirt-guest-agent/scripts/hooks/before_hibernation
%dir %attr (755,root,root) %{_datadir}/ovirt-guest-agent/scripts/hooks/after_hibernation

%config(noreplace) %{_sysconfdir}/ovirt-guest-agent.conf
%config(noreplace) %attr (440,root,root) %{_sysconfdir}/sudoers.d/50_ovirt-guest-agent
%attr (644,root,root) %{_udevrulesdir}/55-ovirt-guest-agent.rules

%doc AUTHORS COPYING NEWS README

%{_datadir}/ovirt-guest-agent/default.conf
%{_datadir}/ovirt-guest-agent/default-logger.conf

%attr (755,root,root) %{_datadir}/ovirt-guest-agent/ovirt-guest-agent.py*
%{_datadir}/ovirt-guest-agent/OVirtAgentLogic.py*
%{_datadir}/ovirt-guest-agent/VirtIoChannel.py*
%{_datadir}/ovirt-guest-agent/GuestAgentLinux2.py*
%{_datadir}/ovirt-guest-agent/timezone.py*
%{_datadir}/ovirt-guest-agent/hooks.py*
%{_datadir}/ovirt-guest-agent/ovirt-locksession
%{_datadir}/ovirt-guest-agent/ovirt-logout
%{_datadir}/ovirt-guest-agent/ovirt-shutdown
%{_datadir}/ovirt-guest-agent/ovirt-hibernate
%{_datadir}/ovirt-guest-agent/ovirt-flush-caches
%{_datadir}/ovirt-guest-agent/ovirt-container-list

# We don't provide single-sign-on support on this distribution
%exclude %{_datadir}/ovirt-guest-agent/CredServer.py*
%exclude %{_sysconfdir}/dbus-1/system.d/org.ovirt.vdsm.Credentials.conf

%{_datadir}/ovirt-guest-agent/scripts/hooks/defaults/55-flush-caches
%attr (755,root,root) %{_datadir}/ovirt-guest-agent/scripts/hooks/defaults/55-flush-caches.sudo
%attr (755,root,root) %{_datadir}/ovirt-guest-agent/scripts/hooks/defaults/flush-caches

# SUDO support script
%attr (755, root, root) %{_datadir}/ovirt-guest-agent/ovirt-hibernate-wrapper.sh
%attr (755, root, root) %{_datadir}/ovirt-guest-agent/ovirt-locksession-wrapper.sh
%attr (755, root, root) %{_datadir}/ovirt-guest-agent/ovirt-logout-wrapper.sh
%attr (755, root, root) %{_datadir}/ovirt-guest-agent/ovirt-shutdown-wrapper.sh
%attr (755, root, root) %{_datadir}/ovirt-guest-agent/ovirt-sudo-wrapper.sh
%attr (755, root, root) %{_datadir}/ovirt-guest-agent/ovirt-container-list-wrapper.sh
%attr (755, root, root) %{_datadir}/ovirt-guest-agent/ovirt-flush-caches-wrapper.sh

# Helper scripts for the daemon
%attr (755,root,root) %{_datadir}/ovirt-guest-agent/LockActiveSession.py*
%attr (755,root,root) %{_datadir}/ovirt-guest-agent/LogoutActiveUser.py*
%attr (755,root,root) %{_datadir}/ovirt-guest-agent/hibernate
%attr (755,root,root) %{_datadir}/ovirt-guest-agent/diskmapper
%attr (755,root,root) %{_datadir}/ovirt-guest-agent/ovirt-osinfo
%attr (755,root,root) %{_datadir}/ovirt-guest-agent/container-list

%config(noreplace) %{_datadir}/ovirt-guest-agent/scripts/hooks/before_hibernation/55_flush-caches
%config(noreplace) %{_datadir}/ovirt-guest-agent/scripts/hooks/before_migration/55_flush-caches
%config(noreplace) %{_sysconfdir}/ovirt-guest-agent/hooks.d/before_hibernation/55_flush-caches
%config(noreplace) %{_sysconfdir}/ovirt-guest-agent/hooks.d/before_migration/55_flush-caches

%if 0%{?suse_version} >= 1210
# systemd service
%{_unitdir}/ovirt-guest-agent.service
%else
# init script
%attr (755,root,root) %{_initddir}/ovirt-guest-agent
%endif
# *suse helper link
%{_sbindir}/rcovirt-guest-agent

%changelog
* Thu Nov  9 2017 boris@steki.net
- update to upstream release 1.0.14
- removed fix-script-name-in-etc-sudoersd-file-for-ovirt.patch
  as it has been fixed upstream
* Wed Feb  8 2017 boris@steki.net
- update to upstream release 1.0.13
* Mon Jun  6 2016 ken@suse.com
- Update to upstream 1.0.12
* Fri Dec 18 2015 boris@steki.net
- update to upstream patch release 1.0.11.2
* Tue Aug 18 2015 evilissimo@redhat.com
- Update to upstream 1.0.11
* Thu Jan 22 2015 evilissimo@redhat.com
- Update to upstream 1.0.10.3
* Wed Oct  1 2014 evilissimo@redhat.com
- Update to upstream 1.0.10.2
* Tue Jul  1 2014 evilissimo@redhat.com
- Update to upstream 1.0.10 version
* Wed Jun 18 2014 evilissimo@redhat.com
- sudoers: fix path to ovirt-shutdown-wrappers.sh
* Thu Apr 10 2014 evilissimo@redhat.com
- Update to upstream 1.0.9 version
* Wed Oct 30 2013 vfeenstr@redhat.com
- Initial package on OBS
* Thu Jul 11 2013 vfeenstr@redhat.com
- Pep8 rules applied on python files
- Call restorecon on pidfile
- Report multiple IPv4 addresses per device if available
- Send 'uninstalled' notification non blocking
- fixed "modified" files after clone.
- rewrote nic's addresses functions in python 2.4 syntax.
- GNOME 3.8 no longer supports gdm plugins. Therefore it's now disabled for
  higher versions
- Added full qualified domain name reporting
- Condrestart now ensures that the pid file does not only exist, but also is
  not empty
- Added new optional parameter for shutdown to allow reboot
* Tue Dec 25 2012 ghammer@redhat.com
- reset user rights on virtio-channel during package removal.
- unification of line endings to unix.
- fixed support for reporting devices with only ipv6.
- fixed pep8 errors in the linux guest agent.
* Wed Dec  5 2012 vfeenstr@redhat.com
- New upstream version 1.0.6
- Upstream build system is now taking care of folder creation
- Upstream build system is now taking care of systemd units installation
* Wed Nov 28 2012 vfeenstr@redhat.com
- License has been changed to Apache Software License 2.0
* Fri Oct 19 2012 vfeenstr@redhat.com
- introduced ovirt-guest-agent-common noarch package which provides
  ovirt-guest-agent and avoids duplication of the same package content
- fixed various rpmlint errors and warnings
- added required build requires
- removed unnecessary build requires
- removed unnecessary call to autoreconf in setup section
- marked config files as such
- excluded unwanted files instead of deleting them
- removed consolehelper based symlinks - now in upstream make install
* Sun May 20 2012 ghammer@redhat.com
- fixed 'udevadm trigger' command line (bz#819945).
- fixed various rpmlint errors and warnings.
* Tue May 15 2012 ghammer@redhat.com
- replaced "with" usage with a python 2.4 compatible way.
- added files to support RHEL-5 distribution.
- added more detailed memory statistics.
- fixed build on fc-17 (use the _unitdir macro).
* Sun Apr 15 2012 ghammer@redhat.com
- removed the RHEL distribution support for the review process.
- removed BuildRoot header and clean section.
- fixed user creation.
* Tue Apr 10 2012 ghammer@redhat.com
- package was renamed to rhevm-guest-agent in RHEL distribution.
- fixed gdm-plugin build requires.
  Resolves: BZ#803503
* Wed Mar 28 2012 ghammer@redhat.com
- included a gpl-v2 copying file.
- build the gdm-plugin using the gdm-devel package.
- added a support for RHEL distribution.
* Wed Feb 22 2012 ghammer@redhat.com
- updated required selinux-policy version (related to rhbz#791113).
- added a support to hibernate (s4) command.
- renamed user name to ovirtguest.
- reset version numbering after changing the package name.
* Tue Sep 27 2011 ghammer@redhat.com
- fixed disk usage report when mount point include spaces.
- added a minimum version for python-ethtool.
  Resolves: BZ#736426
* Thu Sep 22 2011 ghammer@redhat.com
- added a new 'echo' command to support testing.
  Resolves: BZ#736426
* Thu Sep 15 2011 ghammer@redhat.com
- report new network interaces information (ipv4, ipv6 and
  mac address).
- added disks usage report.
- a new json-based protocol with the vdsm.
  Resolves: BZ#729252 BZ#736426
* Mon Aug  8 2011 ghammer@redhat.com
- replaced password masking with a fixed-length string.
  Resolves: BZ#727506
* Thu Aug  4 2011 ghammer@redhat.com
- send an 'uninstalled' notification to vdsm
- mask the user's password in the credentials block
  Resolves: BZ#727647 BZ#727506
* Mon Aug  1 2011 ghammer@redhat.com
- fixed selinux-policy required version.
  Resolves: BZ#694088
* Mon Jul 25 2011 ghammer@redhat.com
- various fixes after failing the errata's rpmdiff.
- added selinux-policy dependency.
  Resolves: BZ#720144 BZ#694088
* Thu Jun 16 2011 ghammer@redhat.com
- read report rate values from configuration file.
- replaced executing privilege commands from sudo to
  consolehelper.
  Resolves: BZ#713079 BZ#632959
* Tue Jun 14 2011 ghammer@redhat.com
- execute the agent with a non-root user.
- changed the shutdown timeout value to work in minutes.
- update pam config files to work with selinux.
- fixed the local user check when stripping the domain part.
  Resolves: BZ#632959 BZ#711428 BZ#694088 BZ#661713 BZ#681123
* Wed May 25 2011 ghammer@redhat.com
- stopped removing the domain part from the user name.
- show only network interfaces that are up and running.
  Resolves: BZ#661713 BZ#681123 BZ#704845
* Mon Apr  4 2011 ghammer@redhat.com
- added kdm greeter plug-in.
  Resolves: BZ#681123
* Mon Mar 14 2011 ghammer@redhat.com
- replaced rhevcredserver execution from blocking main loop to
  context's iteration (non-blocking).
  Resolves: BZ#683493
* Thu Mar 10 2011 ghammer@redhat.com
- added some sleep-ing to init script in order to give udev
  some time to create the symbolic links.
- changed the kernel version condition.
  Resolves: BZ#676625 BZ#681527
* Wed Mar  2 2011 ghammer@redhat.com
- removed unused file (rhevcredserver) from rhel-5 build.
- added udev and kernel minimum version requirment.
- fixed pid file location in spec file.
  Resolves: BZ#681524 BZ#681527 BZ#681533
* Tue Mar  1 2011 ghammer@redhat.com
- updated the agent's makefile to work with auto-tools.
- added sub packages to support the single-sign-on feature.
- added -h parameter to shutdown command in order to halt the vm
  after shutdown.
- converted configuration file to have unix-style line ending.
- added redhat-rpm-config to build requirements in order to
  include *.pyc and *.pyo in the rpm file.
  Resolves: BZ#680107 BZ#661713 BZ#679470 BZ#679451
* Wed Jan 19 2011 ghammer@redhat.com
- fixed files' mode to include execution flag.
  Resolves: BZ#670476
* Mon Jan 17 2011 ghammer@redhat.com
- fixed the way the exit code was returned. the script always
  return 0 (success) because the main program ended and errors
  from the child process were lost.
  Resolves: BZ#658092
* Thu Dec 23 2010 ghammer@redhat.com
- added description to startup/shutdown script in order to support
  chkconfig.
- a temporary fix to the 100%% cpu usage when the vdsm doesn't
  listen to the virtio-serial.
  Resolves: BZ#639702
* Sun Dec 19 2010 ghammer@redhat.com
- BZ#641886: lock command now handle both gnome and kde.
  Resolves: BZ#641886
* Tue Dec  7 2010 bazulay@redhat.com
- BZ#660343 load virtio_console module before starting the daemon.
- BZ#660231 register daemon for startup.
  Resolves: BZ#660343 BZ#660231
* Sun Dec  5 2010 bazulay@redhat.com
- initial build for RHEL-6
- works over vioserial
- Agent reports only heartbeats, IPs, app list
- performs: shutdown & lock (the lock works only on gnome - when
  ConsoleKit & gnome-screensaver is installed)
  Resolves: BZ#613059
* Fri Aug 27 2010 ghammer@redhat.com
- Initial build.
